Monty Python's Flying Circus: Just the Words - Episode 11

# Episode Eleven

Letter (lavatorial humour)
Interruptions
Agatha Christie sketch
Literary football discussion
Interesting people
Undertakers film
Eighteenth-century social legislation
The Battle of Trafalgar
Batley Townswomens' Guild presents the Battle of Pearl Harbour
Undertakers film

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Film: The Amazing World of The 'It's' Man
It's Man | It's...
| Animated titles.
Voice Over | (and CAPTION:) 'MONTY PYTHON'S FLYING CIRCUS'
| CAPTION: 'EPISODE TWO'S' CAPTION: 'THE ROYAL PHILHARMONIC ORCHESTRA GOES TO THE BATCHROOM' Cut to bathroom door, outside. Man knocks on door.
Man | Have you finished in there yet?
| From inside comes a burst of the Tchaikovsky piano concerto. He tuts. Cut to letter and voice over.
First Voice Over | Dear Sir, I object strongly to the obvious lavatorial turn this show has already taken. Why do we never hear about the good things in Britain, like Mary Bignall's wonderful jump in 1964? Yours etc., Ken Voyeur.
| Stock film of Mary Bignall's winning jump at the Rome Olympics. Letter and voice over.
Second Voice Over | Dear Sir, I object strongly to the obvious athletic turn this show has now taken. Why can't we hear more about the human body? There is nothing embarrassing or nasty about the human body except for the intestines and bits of the bottom.
| We see another letter and another voice over.
Third Voice Over | Dear Sir, I object strongly to the letters on your programme. They are clearly not written by the general public and are merely included for a cheap laugh. Yours sincerely etc., William Knickers.
| Stock film of the whole of an orchestra finishing an orchestral item. When they finish playing we hear the sound of flushing.
| ANIMATION: a beautiful and not zany introduction, perhaps with photos of famous historical characters, finishing with the words: 'The World of History '. Cut to man at desk. CAPTION: 'PROFESSOR R. J. CANNING'
Canning | 1348. The Black Death, typhus, cholera, consumption, bubonic plague.
| Cut to five undertakers sitting on a coffin in a country road.
First Undertaker | Ah, those were the days...
| Back to Canning at his desk.
Canning | Now I'm... I'm... Now I'm not prepared to go on with this, unless these interruptions cease. All right? Right. The devastating effect of these, em...
| Cut to film of hearses racing. Crashing out of shot. Sign: 'Accident Black Spot', and the undertakers picnicking.
Canning | (he is packing up his papers and putting on his mac as he walks away from desk, camera pans with him) No, don't follow me and ... (camera zooms in) And don't zoom in on me, no I'm off, I'm off. That's it. That's all. I'm off.
| He walks out of shot. Empty frame. A short pause. An undertaker comes into frame.
Second Undertaker | (to camera) Are you nervy, irritable, depressed, tired of life. (winks) Keep it up.
| Cut to drawing room of large English country house. Sitting around are various standard Agatha Christie type characters, Colonel Pickering, Lady Amanda Velloper, Kirt, Anona Winn. They drink tea, read etc. Outside there is thunder. Inspector Tiger enters the room.
Inspector Tiger | This house is surrounded. I'm afraid I must not ask anyone to leave the room. No, I must ask nobody ... no, I must ask everybody to... I must not ask anyone to leave the room. No one must be asked by me to leave the room. No, no one must ask the room to leave. I ... I ... ask the room shall by someone be left. Not. Ask nobody the room somebody leave shall I. Shall I leave the room? Everyone must leave the room... as it is... with them in it. Phew. Understand?
Colonel Pickering | You don't want anybody to leave the room.
Inspector Tiger | (clicking fingers to indicate Colonel Pickering has hit the nail on the head) Now, alduce me to introlow myslef. I'm sorry. Alself me to myduce introlow myslef. Introme -to-lose mlow alself. Alme to you introself mylowduce. Excuse me a moment. (bangs himself on the side of the head) Allow me to introduce myself. I'm afraid I must ask that no one leave the room. Allow me to introduce myself. I'm Inspector Tiger.
All | Tiger?
Inspector Tiger | (jumping) Where? Where? What? Ah. Me Tiger. You Jane. Grrr. Beg your pardon, allow me to introduce myself I'm afraid I must ask that no one leave the room.
Lady Velloper | Why not?
Inspector Tiger | Elementary. Since the body was found in this room, and no one has left it. Therefore ... the murderer must be somebody in this room.
Colonel Pickering | What body?
Inspector Tiger | Somebody. In this room. Must the murderer be. The murderer of the body is somebody in this room, which nobody must leave... leave the body in the room not to be left by anybody. Nobody leaves anybody or the body with somebody. Everybody who is anybody shall leave the body in the room body. Take the tablets Tiger. Anybody (as he searches for the tablets) with a body but not the body is nobody. Nobody leaves the body in the ... (he takes the tablet) Albody me introbody albodyduce.
| At this moment a surgeon enters with two nurses and starts to operate on his head with sawing noises. CAPTION: 'THE SAME DRAWING ROOM. ONE LOBOTOMY LATER'. The surgeon is packing up. Inspector Tiger's head is bandaged.
Surgeon | Now for Sir Gerald.
Inspector | That's better, now I'm Inspector Tiger and I must ask that nobody leave the room. (he gives thumbs up to the surgeon who is at door) Now someone has committed a murder here, and that murderer is someone in this room. The question is ... who?
Colonel Pickering | Look, there hasn't been a murder.
Inspector Tiger | No murder.
All | No.
Inspector Tiger | Oh. I don't like it. It's too simple, too clear cut. I'd better wait. (he sits on sofa) No, too simple, too clear cut.
| The lights go out. There is a scream followed by a shot. The light goes up. Inspector Tiger is dead. He has a bullet hole in his forehead, an arrow through his neck and there is a bottle marked poison on his lap.
Colonel Pickering | By jove, he was right.
| Chief Superintendent Lookout enters, with constable.
Lookout | This house is surrounded. I must ask that no one leave the room. I'm Chief Superintendent Lookout.
Lady Velloper | Look out?
Lookout | (jumping) What, where, oh, me, Lookout. Lookout of the Yard.
Lady Velloper | Why, what would we see?
Lookout | I'm sorry?
Lady Velloper | What would we see if we look out of the yard?
Lookout | . .. I'm afraid I don't follow that at all. Ah ha. The body. So the murderer must be somebody in this room. Unless he had very long arms. Say thirty or forty feet. I think we can discount that one. Ha, ha, ha, (he starts really laughing) Lookout of the Yard. Very good. Right. Now, we'll reconstruct the crime. I'll sit down here. Constable, you turn off the lights. (lights go out, we hear Lookout's voice) Good. Now then, there was a scream (scream) then just before the lights went up there was a shot.
| There is a shot. The lights go up and Chief Superintendent Lookout is sitting dead, bullet hole, arrow and all. In walks Assistant Chief Constable Theresamanbehindyer.
Theresamanbehindyer | All right... all right, the house is surrounded and nobody leave the room and all the rest of it. Allow me to introduce myself. I'm Assistant Chief Constable Theresamanbehindyer.
All | Theresamanbehindyer?
Theresamanbehindyer | Ah, you're not going to catch me with an old one like that. Right let's reconstruct the crime. Constable you be Inspector Tiger.
Constable | Right, sir. Nobody leave the room ask shall - somebody I leave nobody in the room body shall, take the tablets Tigerbody. Alself me to my duce introlow left body in the roomself.
Theresamanbehindyer | Very good. Just sit down there. Right now we'll pretend the lights have gone out. Constable, you scream. (constable screams) Somebody shoots you (pulls gun and shoots constable through head) and the door opens...
| The door flies open. Enter policeman.
Fire | Nobody move! I'm Chief Constable Fire.
All | Fire! Where?
| He jumps. Immediately cut to undertaker as before.
Second Undertaker | We're interrupting this sketch but we'll be bringing you back the moment anything interesting happens. Meanwhile here are some friends of mine.
| Film of four undertakers carrying a coffin. They surreptitiously tip the body out of the coffin and go skipping lightly up the road. Letter and voice over.
Voice Over | Dear Sir, I'm sorry this letter is late, it should have come at the beginning of the programme. Yours, Ivor Bigbottie, (age two).
| Two chairs in interview set. Smart interviewer and footballer (who is not over bright) in blazer.
Interviewer | From the plastic arts we turn to football. Last night in the Stadium of Light, Jarrow, we witnessed the resuscitation of a great footballing tradition, when Jarrow United came of age, in a European sense, with an almost Proustian display of modern existentialist football. Virtually annihilating by midfield moral argument the now surely obsolescent catennachio defensive philosophy of Signor Alberto Fanffino. Bologna indeed were a side intellectually out argued by a Jarrow team thrusting and bursting with aggressive Kantian positivism and outstanding in this fine Jarrow team was my man of the match, the arch-thinker, free scheming, scarcely ever to be curbed, midfield cognoscento, Jimmy Buzzard.
Buzzard | Good evening Brian.
Interviewer | Jimmy, at least one ageing football commentator was gladdened last night by the sight of an English footballer breaking free of the limpid tentacles of packed Mediterranean defence.
Buzzard | Good evening Brian.
Interviewer | Were you surprised at the way the Italians ceded midfield dominance so early on in the game?
Buzzard | Well Brian... I'm opening a boutique.
Interviewer | This is of course symptomatic of a new breed of footballer as it is indeed symptomatic of your whole genre of player, is it not?
Buzzard | Good evening Brian.
Interviewer | What I'm getting at, Jimmy, is you seem to have discovered a new concept with a mode in which you dissected the Italian defence, last night.
Buzzard | (pauses for thought) I hit the ball first time and there it was in the back of the net. (smiles and looks around)
Interviewer | Do you think Jarrow will adopt a more defensive posture for the first leg of the next tie in Turkey?
Buzzard | (confidently) I hit the ball first time and there it was in the back of the net.
Interviewer | Yes, yes - but have you any plans for dealing with the free-scoring Turkish forwards?
Buzzard | Well Brian... I'm opening a boutique.
| Cut to undertaker.
Second Undertaker | And now let's take a look at the state of play in the detective sketch.
| Cut to drawing room. There is an enormous pile of dead policemen from the Agatha Christie Sketch on and around the sofa.
Constable | Alself me to introlow mybody...
| Inspector shoots him in the head. CAPTION: 'CONSTABLES 13 SUPERINTENDENTS 9' Cut to four undertakers carrying a coffin up a hill. One of them falters and drops. The others lower the coffin to the ground, take out a fresh undertaker, put the fallen one in the coffin, and proceed. Cut to animated sequence, leadning to big glittering flashing lights saying 'Interesting People'. A compère sits at desk, with guest chairs beside it.
Compère | Hello, good evening, and welcome to yet another edition of 'Interesting People'. And my first interesting person tonight is the highly interesting Mr Howard Stools from Kendal in Westmorland.
| He puts a matchbox on desk in front of him. He presses a button on the desk and we hear applause. Releases button; applause stops abruptly. He opens the box a little and speaks into it.
Compère | Good evening Mr Stools.
Voice | (from inside box) Hello, David.
Compère | Mr Stools, what makes you particularly interesting?
Voice | Well, I'm only half an inch long.
Compère | Well that's extremely interesting, thank you for coming along on the show tonight Mr Stools.
Mr Stools | I thought you'd think that was interesting David, in fact...
Compère | (shuts matchbox; applause) Mr Howard Stools from Kendal in Westmorland ... half an inch long. (applause) Our next guest tonight has come all the way from Egypt, he's just flown into London today, he's Mr Ali Bayan, he's with us in the studio tonight and he's stark raving mad.
| Applause. Cut to Ali Bayan who looks at camera in a very mad way. Applause.
Compère | Mr Ali Bayan, stark raving mad. Now it's time for our music spot and we turn the spotlight tonight on the Rachel Toovey Bicycle Choir, (applause) with their fantastic arrangement of 'Men of Harlech' for bicycle bells only.
| Cut to six men in oilskins and sou'westers. They sing 'Men of Harlech ', and at the end of each line mournfully ring bells. Applause at end.
Compère | The Rachel Toovey Bicycle Choir. Really interesting. Remember, if you're interesting and want to appear on this programme, write your name and address and your telephone number and send it to this address: (reads caption) The BBC, c/o E. F. Lutt, 18 Rupee Buildings, West 12. (applause) Thank you, thank you. Now here's an interesting person. Apart from being a full-time stapling machine, he can also give a cat influenza.
| Cut to a smart dressed man who coughs into a cat basket. We hear a meow and a feline sneeze. Cut back to compère.
Compère | Well, you can't get much more interesting than that, or can you? With me now is Mr Thomas Walters of West Hartlepool who is totally invisible. Good evening, Mr Walters. (turns to empty chair)
Walters | (off-screen) Over here, Hughie.
| Compère turns to find a boringly dressed man sitting by him.
Compère | Mr Walters, are you sure you're invisible?
Walters | Oh yes, most certainly.
Compère | Well, Mr Walters, what's it like being invisible?
Walters | (slowly and boringly) Well, for a start, at the office where I work I can be sitting at my desk all day and the others totally ignore me. At home, even though we are in the same room, my wife does not speak to me for hours, people pass me by in the street without a glance in my direction, and I can walk into a room without...
Compère | Well, whilst we've got interesting people, we met Mr Oliver Cavendish who...
Walters | (droning on) ... Even now you yourself, you do hardly notice me...
Compère | Mr Oliver Cavendish of Leicester, who claims to be able to recite the entire Bible in one second, whilst being struck on the head with a large axe. Ha, ha, wow. We've since discovered that he was a fraud, yes a fraud, he did not in fact recite the entire Bible he merely recited the first two words, 'In the...' before his death.
| Cut to film montage of sporting clips.
Compère | (voice over) Now it's time for 'Interesting Sport', and this week it's all-in cricket, live from the Municipal Baths, Croydon.
| Boxing ring; two fully kitted out cricketers, who as the bell goes, approach each other and start hitting each other with cricket bats. Applause.
Compère | With me now is Mr Ken Dove, twice voted the most interesting man in Dorking. Ken, I believe you're interested in shouting.
Dove | (shouting) Yes, I'm interested in shouting all right, by jove you certainly hit the nail on the head with that particular observation of yours then.
Compère | What does your wife think of this?
Wife | (voice off, full-blooded) I agree with him.
Dove | Shut up!
Walters | ... At parties for instance people never come up to me, I just sit there and everybody totally...
| Man holding cat enters.
Compère | That is Tiddles, I believe?
Man | Yes, this is, this is Tiddles.
Compère | Yes, and what does she do?
Man | She flies across the studio and lands in a bucket of water.
Compère | By herself?
Man | No, I fling her.
Compère | Well that's extremely interesting, Ladies and gentlemen - Mr Don Savage and Tiddles.
| Man whirls the cat round and round. He lets go of the cat, it flies across studio. A hollow splash and a meow. Quick shot of a real cat sitting in a bucket.
Dove | (shouting) I'm more interesting than a wet pussycat.
Walters | ... for hour after hour... (we see only his empty chair)
Compère | Yes, great, well now for the first lime on television 'Interesting People' brings you a man who claims he can send bricks to sleep by hypnosis. Mr Keith Maniac from Guatemala.
| Maniac is sitting by compère. He wears a top hat and an opera cloak.
Maniac | Good evening.
Compère | Keith, you claim you can send bricks to sleep.
Maniac | Yes, that is correct, I can...
Compère | Entirely by hypnosis.
Maniac | Yes ... I use no artificial means, whatsoever. (leans and picks matchbox off desk to light pipe, opens it and strikes match)
Voice | (from matchbox) Aaagh!
Dove | You've injured Mr Stools!
Maniac | (picks up other box and lights pipe) I simply stare at the brick and it goes to sleep.
Compère | Well, we have a brick here, Keith. (indicates brick on desk) Perhaps you can send it to sleep for us...
Maniac | Oh ... Ah, well, I am afraid that is already asleep.
Compère | How do you know?
Maniac | Well, it's not moving ....
Compère | Oh, I see - have we got a moving brick? Yes, we've got a moving brick, Keith, it's coming over now.
| We see a man in a white coat preparing to throw brick. He throws it gently. It lands on the desk in front of Keith. Keith stares at it as it falls.
Maniac | There we are, fast asleep.
Compère | Very good, very good indeed.
Maniac | All done with the eyes.
Compère | Yes, Mr Keith Maniac from Guatemala.
Dove | (distressed - to matchbox) Mr Stools - speak to me, Howard.
| Quick cut back to all-in cricket.
Compère | Mr Keith Maniac of Guatemala... and now four tired undertakers.
| Cut to film of four undertakers struggling up a hill carrying a coffin. One staggers and drops. The others lower the coffin, pick him up, and place him inside. Raising the coffin again they stagger off up the hill. Another undertaker collapses; the remaining two place him in the coffin. Exhaustedly they pick up the coffin, but have only gone two or three paces when one of them collapses. The remaining one drags him into the coffin, pushing him in with some difficulty, and forces the lid shut. He debates with himself for a moment on how to pick up the coffin, then disgustedly throws away his hat and climbs into the coffin, shutting the lid behind him. The coffin moves off by itself.
Voice Over | We interrupt this very quickly to take you back to the Jimmy Buzzard interview, where we understand something exciting's just happened.
| Cut back to the interview studio; Jimmy Buzzard is sitting on the floor.
Buzzard | I've fallen off my chair, Brian.
| Cut to a graveyard. The coffin, still moving of its own volition, enters the graveyard. A vicar walks up and motions gravediggers (who we cannot see) to get out of the grave. Out of the grave climb two gravediggers. . . then two more... then two more... yet another two... two miners ... two uniformed men... a police dog with handler... and finally an Australian surfboarder. The coffin makes its way into the grave. Then a wonderful piece of animation by the amazing animator Terry Gilliam, wonderboy. Consisting of a very fast collage of extremely sexy stills of half-dressed and naked girls.
| Incredibly torchy music, after eight seconds of which: SUPERIMPOSED CAPTION: 'THE WORLD OF HISTORY' SECOND CAPTION: 'SOCIAL LEGISLATION IN THE EIGHTEENTH CENTURY' Cut to fantastically alluring boudoir: a plush four poster bed with silk drapes, silk sheets, a fur pillow etc. We look down on it from above. Stretched out on the bed is a girl (Carol) oozing with sex... a real professional... black net stocking, suspenders, bra and panties or what have you. She moves as if in the throes of orgasm as she mimes to a very masculine voice off. SUPERIMPOSED CAPTION: 'A. J. P. TAYLOR'
Voice Over | (very masculine voice to which girl mimes) Good evening. Tonight I want to examine the whole question of eighteenth-century social legislation - its relevance to the hierarchical structure of post-Renaissance society, and its impact on the future of parochial organization in an expanding agrarian economy. But first a bit of fun.
| Cut to film of eight-second striptease. Cut immediately back to the same set.
Voice Over | To put England's social legislation in a European context is Professor Gert Van Der Whoops of the Rijksmuseum in the Hague.
| Cut to another bed, equally seductive. A little bespectcled professor is lying on it being caressed and undressed by an amorous siren.
Professor | (German accent) In Holland in the early part of the fifteenth century there was three things important to social legislation. One ... rise of merchant classes ... two, urbanization of craft guilds... three, declining moral values in age of increasing social betterment. But first, a bit of fun ... (grabs girl)
| A curtain and potted palms. Sound effects: angel choirs. A man in dinner jacket with angel's wings on is lowered from above. As he touches the ground the angel choirs fade out. He gets a crumpled piece of paper out of his pocket.
Man | And now Professor R.J. Canning.
| He folds up the paper and puts it away. The angel choirs start again and he slowly rises up and out of frame. Cut to Professor Canning in straight presentation-type set with BP screen behind him. CAPTION: 'PROFESSOR R. J. CANNING AGAIN'
Canning | The cat sat on the mat. And now the Battle of Trafalgar... (on the screen behind him a contemporary piaure of the Battle of Trafalgar flashes up) Tonight we examine popular views of this great battle. Was the Battle of Trafalgar fought in the Atlantic off southern Spain? Or was it fought on dry land near Cudworth in Yorkshire? Here is one man who thinks it was...
| Cut to a man - a Gumby - with gum boots on, rolled up trousers, knotted handkerchief etc., looking very thick and standing in the middle of a field.
Canning | (voice over) And here is his friend.
| Camera pans lightly losing Gumby but revealing identically dressed thick man standing next to him. The camera pans back to original Gumby. SUPERIMPOSED CAPTION: 'PROFFESOR R. J. GUMBY'
Canning | (voice over) What makes you think the Battle of Trafalgar was fought near Cudworth?
| There is a long pause.
First Gumby | Because ... Drake ... was ... too ... clever for... the German ... fleet.
Canning | (voice over) I beg your pardon?
First Gumby | ... Oh I've forgotten what I said now.
Canning | (voice over) Mr Gumby's remarkable views have sparked off a wave of controversy amongst his fellow historians.
| Cut to identical Gumby figure in book lined study. He stands. SUPERIMPOSED CAPTION: 'F. H. GUMBY. REGIUS PROFESSOR OF HISTORY AT HIS MOTHER'S'
Second Gumby | Well I rink ... we ... should ... reappraise ... our concept of the ... Battle of Trafalgar.
| Cut to another Gumby, this time outside a university. SUPERIMPOSED CAPTION: 'PROF. L. R. GUMBY'
Third Gumby | Well... well... I agree with everything Mr Gumby says.
| Cut to yet another Gumby. This time standing in a pig-sty with pigs. SUPERIMPOSED CAPTION: 'PROF. ENID GUMBY'
Fourth Gumby | Well, I think cement is more interesting than people think.
| Original sexy girl in seductive boudoir as she mimes to masculine voice over. SUPERIMPOSED CAPTION AS BEFORE: 'A. J. P. TAYLOR'
Voice Over | One subject... four different views ... (brandishing egg-whisk) twelve and six... in a plain wrapper.
| Cut back to Canning.
Canning | The stuff of history is indeed woven in the woof. Pearl Harbour. There are pages in history's book which are written on the grand scale. Events so momentous that they dwarf man and time alike. And such is the Battle of Pearl Harbour, re-enacted for us now by the women of Barley Townswomen's Guild.
| Cut to a muddy corner of a field. Miss Rita Fairbanks stands talking straight to camera. Behind her lurk five more pepperpots.
Canning | (voice over) Miss Rita Fairbanks - you organized this reconstruction of the Battle of Pearl Harbour - why?
Rita | Well we've always been extremely interested in modern drama ... we were of course the first Townswomen's Guild to perform 'Camp On Blood Island', and last year we did our extremely popular re-enactment of 'Nazi War Atrocities'. So this year we thought we would like to do something in a lighter vein...
Canning | So you chose the Battle of Pearl Harbour?
Rita | Yes, that's right, we did.
Canning | Well I can see you're all ready to go. So I'll just wish you good luck in your latest venture.
Rita | Thank you very much, young man.
| She retreats, and joins the other ladies who meanwhile separate into two opposing sides facing each other.
Canning | (reverential voice over) Ladies and gentlemen, the World of History is proud to present the premiere of the Batley Townswomen's Guild's re-enactment of 'The Battle of Pearl Harbour'.
| A whistle blows and the two sides set about each other with handbags etc., speeded up 50% just to give it a bit of edge. Cut to Canning in studio.
Canning | The Battle of Pearl Harbour. Incidentally, I'm sorry if I got a little bit shirty earlier on in the programme, when I kept getting interrupted by all these films and things that kept coming in, but I...
| Cut to vicar in a graveyard He sprinkles dirt and gets mud thrown in his face. Vicar shoots a gun. Cut to undertakers leaving graveyard. They get into a hearse. As they leave it and drive off we see the other side is painted with psychedelic flowers. Cut to Canning.
Canning | So I said if it happened again I'd get very angry and talk to Lord Hill and...
| Cut to 'It's' man.
Canning | Tell Lord Hill.
| CREDITS